@@ -1,6 +1,6 @@
 
-library(rootSolve)      #multiroot
-library(numDeriv)       #jacobian
+#library(rootSolve)      #multiroot
+#library(numDeriv)       #jacobian
 
 #######################
 #
@@ -153,4 +153,4 @@ condGEE <- function(data, start, mu.fn=MU, mu.d=MU.d, var.fn=V, k1=K1.norm, k2=K
  }
 
  return(list(eta=eta, a.var=a.var))
-}
\ No newline at end of file
+}
